autowisp.processing_steps.calculate_photref_merit module — AutoWISP documentation

# autowisp.processing_steps.calculate_photref_merit module

## Class Inheritance Diagram

Sort DR files by their single photometric reference merit function.

autowisp.processing_steps.calculate_photref_merit.calculate_photref_merit(dr_filenames, config)

  Avoid pollutin global namespace.

autowisp.processing_steps.calculate_photref_merit.get_center_background(dr_file, header, fit_terms_expression, *, error_avg, rej_level, max_rej_iter, **dr_path_substitutions)

  Estimate the sky background at the center of the frame.

  Fit a smooth function of position to the background measurements from shape fitting and evaluate it at the center of the frame.

autowisp.processing_steps.calculate_photref_merit.get_center_zenith_distance(header, astrometry, config)

  Return the zenith distance of the center of the frame.

autowisp.processing_steps.calculate_photref_merit.get_frame_merit_info(dr_fname, typical_star, bg_fit_config, config, **dr_path_substitutions)

  Return the properties relevant for calculating the merit of given DR.

autowisp.processing_steps.calculate_photref_merit.get_matched_sources(dr_fname, dr_path_substitutions)

  Convenience wrapper around DataReductionFile.get_matched_sources().

autowisp.processing_steps.calculate_photref_merit.get_typical_star(dr_fnames, source_average='median', frame_average='median', **dr_path_substitutions)

  Return the average of the matched sources in all DR files.

  For each DR file the properties of the matched stars (i.e. everything from the catalog and source extraction) are averaged and then another average is computed over the DR files.

  Parameters:

    - dr_fnames ([str]) – The filenames of the DR files to get the typical star for.

    - source_average ('mean'|'median') – How to avarage source properties within a single DR file.

    - frame_average ('mean'|'median') – How the average accross DR files the the already averaged per DR file properties

    - dr_path_substitutions (dict) – Substitutions required to uniquely identify the datasets within the DR file to process.

  Returns:

    The double averaged matched star properties.

  Return type:

    pandas.Series

autowisp.processing_steps.calculate_photref_merit.parse_command_line(*args)

  Return the parsed command line arguments.